@@ -1,3 +1,4 @@
+import multiprocessing as mp
 import os
 from collections import defaultdict
 from typing import Any
@@ -21,8 +22,15 @@ class PatchedFile:
 
 
 class SecretsCollection:
-    def __init__(self) -> None:
+    def __init__(self, root: str = '') -> None:
+        """
+        :param root: if specified, will scan as if the root was the value provided,
+            rather than the current working directory. We still store results as if
+            relative to root, since we're running as if it was in a different directory,
+            rather than scanning a different directory.
+        """
         self.data: Dict[str, Set[PotentialSecret]] = defaultdict(set)
+        self.root = root
 
     @classmethod
     def load_from_baseline(cls, baseline: Dict[str, Any]) -> 'SecretsCollection':
@@ -38,9 +46,26 @@ class SecretsCollection:
     def files(self) -> Set[str]:
         return set(self.data.keys())
 
+    def scan_files(self, *filenames: str, num_processors: Optional[int] = None) -> None:
+        """Just like scan_file, but optimized through parallel processing."""
+        if len(filenames) == 1:
+            self.scan_file(filenames[0])
+            return
+
+        if not num_processors:
+            num_processors = mp.cpu_count()
+
+        with mp.Pool(processes=num_processors) as p:
+            for secrets in p.imap_unordered(
+                _scan_file_and_serialize,
+                [os.path.join(self.root, filename) for filename in filenames],
+            ):
+                for secret in secrets:
+                    self[os.path.relpath(secret.filename, self.root)].add(secret)
+
     def scan_file(self, filename: str) -> None:
-        for secret in scan.scan_file(filename):
-            self[secret.filename].add(secret)
+        for secret in scan.scan_file(os.path.join(self.root, filename)):
+            self[filename].add(secret)
 
     def scan_diff(self, diff: str) -> None:
         """
@@ -262,3 +287,8 @@ class SecretsCollection:
             output[filename] = self[filename]
 
         return output
+
+
+def _scan_file_and_serialize(filename: str) -> List[PotentialSecret]:
+    """Used for multiprocessing, since lambdas can't be serialized."""
+    return list(scan.scan_file(filename))
