@@ -43,6 +43,15 @@ def configure_settings_from_baseline(baseline: Dict[str, Any], filename: str = '
                 file_hash=config['file_hash'],
             )
 
+        if 'detect_secrets.filters.gibberish.should_exclude_secret' in settings.filters:
+            config = settings.filters['detect_secrets.filters.gibberish.should_exclude_secret']
+
+            from detect_secrets import filters
+            filters.gibberish.initialize(
+                model_path=config.get('model'),
+                limit=config['limit'],
+            )
+
     if filename:
         settings.filters['detect_secrets.filters.common.is_baseline_file'] = {
             'filename': filename,
@@ -79,10 +88,40 @@ def transient_settings(config: Dict[str, Any]) -> Generator['Settings', None, No
 
 
 def cache_bust() -> None:
-    get_settings.cache_clear()
-    get_filters.cache_clear()
     get_plugins.cache_clear()
 
+    get_filters.cache_clear()
+    for path, config in get_settings().filters.items():
+        # Need to also clear the individual caches (e.g. cached regex patterns).
+        parts = urlparse(path)
+        if not parts.scheme:
+            module_path, _ = path.rsplit('.', 1)
+            try:
+                module = import_module(module_path)
+            except ModuleNotFoundError:
+                continue
+        elif parts.scheme == 'file':
+            file_path = path[len('file://'):].split('::')[0]
+            try:
+                module = import_file_as_module(file_path)
+            except (FileNotFoundError, InvalidFile):
+                continue
+        else:
+            continue
+
+        for item_key in dir(module):
+            item = getattr(module, item_key)
+            try:
+                if item.__module__ != module_path:
+                    # Make sure we only clear the cache specific to the module.
+                    raise AttributeError
+
+                item.cache_clear()
+            except AttributeError:
+                pass
+
+    get_settings.cache_clear()
+
 
 class Settings:
     DEFAULT_FILTERS = {
@@ -109,6 +148,9 @@ class Settings:
                 'detect_secrets.filters.heuristic.is_templated_secret',
                 'detect_secrets.filters.heuristic.is_prefixed_with_dollar_sign',
                 'detect_secrets.filters.heuristic.is_indirect_reference',
+                'detect_secrets.filters.heuristic.is_lock_file',
+                'detect_secrets.filters.heuristic.is_not_alphanumeric_string',
+                'detect_secrets.filters.heuristic.is_swagger_file',
             }
         }
 
@@ -129,6 +171,7 @@ class Settings:
             name = plugin.pop('name')
             self.plugins[name] = plugin
 
+        get_plugins.cache_clear()
         return self
 
     def disable_plugins(self, *plugin_names: str) -> 'Settings':
@@ -138,6 +181,7 @@ class Settings:
             except KeyError:
                 pass
 
+        get_plugins.cache_clear()
         return self
 
     def configure_filters(self, config: List[Dict[str, Any]]) -> 'Settings':
@@ -162,12 +206,14 @@ class Settings:
             path = filter_config['path']
             self.filters[path] = filter_config
 
+        get_filters.cache_clear()
         return self
 
     def disable_filters(self, *filter_paths: str) -> 'Settings':
         for filter_path in filter_paths:
             self.filters.pop(filter_path, None)
 
+        get_filters.cache_clear()
         return self
 
     def json(self) -> Dict[str, Any]:
